@@ -678,6 +678,18 @@ class UBXMessage:
 
         return self._payload
 
+    @property
+    def msgmode(self) -> int:
+        """
+        Message mode getter.
+
+        :return: msgmode as integer
+        :rtype: int
+
+        """
+
+        return self._mode
+
     @staticmethod
     def msgclass2bytes(msgClass: int, msgID: int) -> bytes:
         """
