@@ -69,6 +69,8 @@ UBX_CONFIG_DATABASE = {
     "CFG_BATCH_PIOID": (0x20260019, U1),
     "CFG_BATCH_EXTRAPVT": (0x1026001A, L),
     "CFG_BATCH_EXTRAODO": (0x1026001B, L),
+    # CFG_BDS BeiDou system configuration
+    "CFG_BDS_USE_PRN_1_TO_5": (0x10340014, L),
     # CFG_GEOFENCE Geofencing configuration
     "CFG_GEOFENCE_CONFLVL": (0x20240011, E1),
     "CFG_GEOFENCE_USE_PIO": (0x10240012, L),
@@ -663,21 +665,21 @@ UBX_CONFIG_DATABASE = {
     # CFG_TMODE Time mode configuration
     "CFG_TMODE_MODE": (0x20030001, E1),
     "CFG_TMODE_POS_TYPE": (0x20030002, E1),
-    "CFG_TMODE_ECEF_X": (0x20030003, I4),
-    "CFG_TMODE_ECEF_Y": (0x20030004, I4),
-    "CFG_TMODE_ECEF_Z": (0x20030005, I4),
+    "CFG_TMODE_ECEF_X": (0x40030003, I4),
+    "CFG_TMODE_ECEF_Y": (0x40030004, I4),
+    "CFG_TMODE_ECEF_Z": (0x40030005, I4),
     "CFG_TMODE_ECEF_X_HP": (0x20030006, I1),
     "CFG_TMODE_ECEF_Y_HP": (0x20030007, I1),
     "CFG_TMODE_ECEF_Z_HP": (0x20030008, I1),
-    "CFG_TMODE_LAT": (0x20030009, I4),
-    "CFG_TMODE_LON": (0x2003000A, I4),
-    "CFG_TMODE_HEIGHT": (0x2003000B, I4),
+    "CFG_TMODE_LAT": (0x40030009, I4),
+    "CFG_TMODE_LON": (0x4003000A, I4),
+    "CFG_TMODE_HEIGHT": (0x4003000B, I4),
     "CFG_TMODE_LAT_HP": (0x2003000C, I1),
     "CFG_TMODE_LON_HP": (0x2003000D, I1),
     "CFG_TMODE_HEIGHT_HP": (0x2003000E, I1),
-    "CFG_TMODE_FIXED_POS_ACC": (0x2003000F, U4),
-    "CFG_TMODE_SVIN_MIN_DUR": (0x20030010, U4),
-    "CFG_TMODE_SVIN_ACC_LIMIT": (0x20030011, U4),
+    "CFG_TMODE_FIXED_POS_ACC": (0x4003000F, U4),
+    "CFG_TMODE_SVIN_MIN_DUR": (0x40030010, U4),
+    "CFG_TMODE_SVIN_ACC_LIMIT": (0x40030011, U4),
     # CFG_TP Timepulse configuration
     "CFG_TP_PULSE_DEF": (0x20050023, E1),
     "CFG_TP_PULSE_LENGTH_DEF": (0x20050030, E1),
