@@ -328,29 +328,29 @@ UBX_PAYLOADS_SET = {
         "reserved4": U4,
     },
     "CFG-NAVX5": {
+        "version": U2,
         "mask1": X2,
-        "reserved0": U4,
-        "reserved1": U1,
-        "reserved2": U1,
+        "mask2": X4,
+        "reserved0": U2,
         "minSVs": U1,
         "maxSVs": U1,
         "minCNO": U1,
-        "reserved5": U1,
+        "reserved1": U1,
         "iniFix3D": U1,
-        "reserved6": U1,
-        "reserved7": U1,
-        "reserved8": U1,
+        "reserved2": U2,
+        "ackAiding": U1,
         "wknRollover": U2,
-        "reserved9": U1,
-        "reserved10": U1,
-        "reserved11": U1,
+        "sigAttenCompMode": U1,
+        "reserved3": U1,
+        "reserved4": U2,
+        "reserved5": U2,
         "usePPP": U1,
-        "useAOP": U1,
-        "reserved12": U1,
-        "reserved13": U1,
+        "aopCfg": U1,
+        "reserved6": U2,
         "aopOrbMaxErr": U2,
-        "reserved3": U4,
-        "reserved4": U4,
+        "reserved7": U4,
+        "reserved8": U3,
+        "useAdr": U1,
     },
     "CFG-NMEAvX": {  # deprecated length 4
         "filter": X1,
